JsonCodec class final

Implemented types

Constructors

JsonCodec({TypeRegistry typeRegistry = const TypeRegistry.empty(), bool permissiveEnums = false, bool ignoreUnknownFields = true, bool supportNamesWithUnderscores = false})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignoreUnknownFields → bool
final
isBinary → bool
Returns true if the marshalled data is binary for this codec.
no setter
name → String
Name of the Codec.
no setteroverride
permissiveEnums → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportNamesWithUnderscores → bool
final
typeRegistry → TypeRegistry
final

Methods

decode(Uint8List data, Object message) → void
override
encode(Object message) → Uint8List
Encode encodes the given message.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stableEncode(Object message) → Uint8List
Encodes the given message with stable field ordering.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited